Re: master d423017cae1: * lisp/vc/vc-dir.el (vc-dir-headers): Try a hints separator line.

Dmitry Gutov <[email protected]>
Newsgroups gmane.emacs.devel
Message-ID <[email protected]>
On 14/08/2026 16:43, Sean Whitton wrote:
> Dmitry Gutov [14/Aug  4:20pm +03] wrote:
>> On 14/08/2026 13:52, Sean Whitton wrote:
>>> Unfortunately I don't think so, take a look at this:
>>
>> Is this text terminal?
> 
> Yes.  foot.
> 
>> How did you make the line thin? :)
> 
> I don't know!

Ah, it's actually the default look - I've changed the color in my init 
script and inadvertently overwrote the other details.

>> I suppose you mean the the asymmetry to be the main problem. That kind
>> of looks fine personally, better than a waste of space, from my PoV.
> 
> I'm inclined to think the asymmetry is worse, but would welcome other's
> points of view.
> 
>> Another thing I wanted to suggest is to have a separate path on the
>> terminal, rendering the separator as underline on the preceding line.
>> Haven't tested it though - could be both a hassle to implement, and
>> still not ideal visually.
> 
> Would love to see that patch, sounds plausible.

I've tested that approach - and maybe let's not.

But how about this one? strike-through goes right through the middle. 
Not sure why Lars chose underline originally - this seems to work fine 
on all the terminal emulators I've tested, and where it doesn't (tty), 
neither does underline.

diff --git a/lisp/simple.el b/lisp/simple.el
index 1f7d57f299a..f3c9994814e 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -749,7 +749,7 @@ separator-line
      (((type graphic) (background light))
       :height 0.1 :background "#a0a0a0")
      (t
-     :foreground "ForestGreen" :underline t))
+     :foreground "ForestGreen" :strike-through t))
    "Face for separator lines."
    :version "29.1"
    :group 'text)
@@ -760,12 +760,12 @@ make-separator-line

  If LENGTH is nil, use the window width."
    (if (or (display-graphic-p)
-          (display-supports-face-attributes-p '(:underline t)))
+          (display-supports-face-attributes-p '(:strike-through t)))
        (if length
            (concat (propertize (make-string length ?\s) 'face 
'separator-line)
                    "\n")
          (propertize "\n" 'face '(:inherit separator-line :extend t)))
     ;; In terminals (that don't support underline), use a line of dashes.
dashes.
      (concat (propertize (make-string (or length (1- (window-width))) ?-)
                          'face 'separator-line)
@@ -760,12 +760,12 @@ make-separator-line
                    "\n")
          (propertize "\n" 'face '(:inherit separator-line :extend t)))
-    ;; In terminals (that don't support underline), use a line of dashes.
+    ;; In terminals that don't support strike-through, use a line of 
dashes.
      (concat (propertize (make-string (or length (1- (window-width))) ?-)
              "\n")))
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.